import classNames from "classnames";

type ButtonProps = {
  variant: "primary" | "secondary";
  size: "sm" | "md" | "lg";
  active?: boolean;
  loading?: boolean;
  disabled?: boolean;
  children: React.ReactNode;
} & React.ButtonHTMLAttributes<HTMLButtonElement>;

const Button = ({
  variant,
  size,
  active,
  loading,
  disabled,
  children,
  ...buttonProps
}: ButtonProps) => {
  const buttonClass = classNames(
    "flex items-center justify-center gap-2 font-bold rounded-xl cursor-pointer box-border",
    {
      "px-4 py-2 text-sm": size === "sm",
      "px-5 py-2.5 text-base": size === "md",
      "px-8 py-4 text-lg": size === "lg",
      "bg-[var(--primary-bg-color)] text-[var(--primary-text-color)] hover:bg-indigo-500 hover:text-white":
        variant === "primary" && !disabled,
      "bg-purple-700 text-white border border-purple-700 hover:bg-white hover:text-gray-600":
        variant === "secondary" && !disabled,

      "bg-indigo-500 text-white": active,

      "bg-[var(--disabled-button-bg)] text-gray-400 pointer-events-none":
        disabled,
    }
  );

  const loaderClass = classNames(
    "border border-gray-300 border-t-2 border-t-blue-600 rounded-full animate-spin",
    {
      "w-2.5 h-2.5": size === "sm",
      "w-3.5 h-3.5": size === "md",
      "w-5 h-5": size === "lg",
    }
  );
  return (
    <button className={buttonClass} {...buttonProps}>
      {loading && (
        <>
          <div className={loaderClass}></div>
          <span>Loading</span>
        </>
      )}
      {!loading && children}
    </button>
  );
};

export default Button;
