import ReactMarkdown from "react-markdown";

type BlogDetailProps = {
  title: string;
  postedOn: string;
  postedBy: string;
  tag: string;
  readTime: string;
  img: string;
  content: string;
};

function BlogDetail({
  title,
  postedOn,
  postedBy,
  tag,
  readTime,
  img,
  content,
}: BlogDetailProps) {
  return (
    <article className="w-[85%] mx-auto">
      <section
        className={
          "font-[Playfair-Medium] max-w-[85%] text-[30px] text-[var(--primary-text-color)] box-border pl-12 "
        }
      >
        <p>{title}</p>
        <div
          className={"flex font-[Inter-Regular] text-[15px] gap-[2rem] pt-4"}
        >
          <div className="text-[var(--secondary-text-color)]">
            Posted on{" "}
            <span className="font-bold text-[var(--primary-text-color)]">
              {postedOn}
            </span>
          </div>
          <div className="text-[var(--secondary-text-color)]">
            By{" "}
            <span className="font-bold text-[var(--primary-text-color)]">
              {postedBy}
            </span>
          </div>
          <div className="text-[var(--secondary-text-color)]">
            Published in{" "}
            <span className="font-bold text-[var(--primary-text-color)]">
              {tag}
            </span>
          </div>
          <div className="font-bold text-[var(--primary-text-color)]">
            {readTime} <span>min read</span>
          </div>
        </div>
      </section>

      <section className={"rounded py-[2rem] w-[100%]"}>
        <img
          className="rounded-md block w-full object-cover"
          src={img || "https://picsum.photos/1000/400"}
          alt={title}
        />
      </section>
      <section
        className={
          "p-8 font-[Inter-Medium] w-full rounded-md bg-[var(--primary-bg-color)] text-[var(--primary-text-color)]"
        }
      >
        <ReactMarkdown>{content}</ReactMarkdown>
      </section>
    </article>
  );
}

export default BlogDetail;
